@@ -1,6 +1,6 @@
 # python3
 # -*- coding: utf-8 -*-
-# @Time    : 2022/1/16 22:21
+# @Time    : 2022/1/16 10:36
 # @Author  : yzyyz
 # @Email   :  youzyyz1384@qq.com
 # @File    : word_analyze.py
@@ -8,19 +8,16 @@
 
 from nonebot import on_command, logger, on_message
 from nonebot.adapters.cqhttp import Bot, GroupMessageEvent, MessageSegment
-from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER
 from nonebot.permission import SUPERUSER
 from .utils import init, replace_tmr
-from pathlib import Path
 import os
-from os.path import dirname
 from pathlib import Path
 
 config_path = Path() / "config"
 word_path = config_path / "word_config.txt"
 words_path = Path() / "config" / "words"
 img_path = Path() / "resource" / "imgs"
-
 word_start = on_command("记录本群", block=True, priority=2, permission=GROUP_ADMIN | GROUP_OWNER | SUPERUSER)
 
 
@@ -78,7 +75,8 @@ async def _(bot: Bot, event: GroupMessageEvent):
         txt = jieba.lcut(text)
         string = " ".join(txt)
         try:
-            wc = WordCloud(font_path=str(ttf_name.resolve()), width=800, height=600, mode='RGBA', background_color="#ffffff").generate(
+            wc = WordCloud(font_path=str(ttf_name.resolve()), width=800, height=600, mode='RGBA',
+                           background_color="#ffffff").generate(
                 string)
             img = Path(img_path / f"{gid}.png")
             wc.to_file(img)
